Polynomials
===========

Polynomial Rings
----------------

.. toctree::
   :maxdepth: 1

   sage/rings/polynomial/polynomial_ring_constructor

Univariate Polynomials
----------------------

.. toctree::
   :maxdepth: 1

   polynomial_rings_univar
   sage/rings/polynomial/convolution
   sage/rings/polynomial/cyclotomic

Multivariate Polynomials
------------------------

.. toctree::
   :maxdepth: 1

   polynomial_rings_multivar
   invariant_theory
   polynomial_rings_toy_implementations

Rational Functions
------------------

.. toctree::
   :maxdepth: 1

   sage/rings/fraction_field
   sage/rings/fraction_field_element
   sage/rings/fraction_field_FpT

Laurent Polynomials
-------------------

.. toctree::
   :maxdepth: 1

   sage/rings/polynomial/laurent_polynomial_ring_base
   sage/rings/polynomial/laurent_polynomial_ring
   sage/rings/polynomial/laurent_polynomial
   sage/rings/polynomial/omega

Infinite Polynomial Rings
-------------------------

.. toctree::
   :maxdepth: 1

   sage/rings/polynomial/infinite_polynomial_ring
   sage/rings/polynomial/infinite_polynomial_element

   sage/rings/polynomial/symmetric_ideal
   sage/rings/polynomial/symmetric_reduction

Tropical Polynomials
--------------------

.. toctree::
   :maxdepth: 1

   sage/rings/semirings/tropical_polynomial
   sage/rings/semirings/tropical_mpolynomial
   sage/rings/semirings/tropical_variety

Boolean Polynomials
-------------------

.. ONLY:: feature_sage_rings_polynomial_pbori

   .. toctree::
      :maxdepth: 1

      sage/rings/polynomial/pbori/pbori

.. include:: ../footer.txt
